Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5786)

Unified Diff: chrome/test/worker/test_worker_main.cc

Issue 66043: Make OSX TestShell able to run workers, using a new test_worker.dylib which i... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/worker/test_worker.exp ('k') | webkit/tools/test_shell/test_shell.gyp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/worker/test_worker_main.cc
===================================================================
--- chrome/test/worker/test_worker_main.cc (revision 13023)
+++ chrome/test/worker/test_worker_main.cc (working copy)
@@ -9,6 +9,7 @@
#include "base/logging.h"
#include "base/path_service.h"
#include "base/scoped_ptr.h"
+#include "base/string_util.h"
#include "chrome/worker/worker_webkitclient_impl.h"
#include "chrome/test/worker/test_webworker.h"
#include "googleurl/src/gurl.h"
@@ -26,6 +27,10 @@
// WebKit client used in DLL.
static scoped_ptr<WorkerWebKitClientImpl> webkit_client;
+#if defined(COMPILER_GCC)
+#pragma GCC visibility push(default)
+#endif
+extern "C" {
// DLL entry points
WebWorker* API_CALL CreateWebWorker(WebWorkerClient* webworker_client,
TestWebWorkerHelper* webworker_helper) {
@@ -40,11 +45,16 @@
return NULL;
#endif
}
+} // extern "C"
-// WebKit glue functions
-
+// WebKit glue stub functions.
namespace webkit_glue {
+#if defined(COMPILER_GCC)
+// GCC hides the class methods like this by default, even in the scope
+// of the "#pragma visibility". Need the attribute.
+__attribute__((visibility("default")))
+#endif
ResourceLoaderBridge* ResourceLoaderBridge::Create(
const std::string& method,
const GURL& url,
@@ -62,7 +72,7 @@
}
string16 GetLocalizedString(int message_id) {
- return L"";
+ return EmptyString16();
}
std::string GetDataResource(int resource_id) {
@@ -145,4 +155,8 @@
}
#endif
-}
+} // namespace webkit_glue
+
+#if defined(COMPILER_GCC)
+#pragma GCC visibility pop
+#endif
« no previous file with comments | « chrome/test/worker/test_worker.exp ('k') | webkit/tools/test_shell/test_shell.gyp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698